@@ -7,7 +7,6 @@
 #'
 #' @return the full URL for the desired example
 #' @export
-#' @return an URL string
 #'
 #' @examples
 #' examples_url("battery.dat") |> read.table(header=TRUE)
@@ -17,3 +16,17 @@ examples_url <- function(example) {
 }
 
 
+#' Expand a formula
+#'
+#' @param f a formula
+#'
+#' @returns a formula after expansion, e.g. `Y ~ A + B` becomes `Y ~ A + B + A:B`
+#' @export
+#'
+#' @examples
+#' expand_formula(Y ~ (A + B)^3)
+expand_formula <- function(f) {
+  stopifnot(inherits(f, "formula"))
+  reformulate(labels(terms(f)), f[[2]])
+}
+
